Stan Math Library: stan/math/prim/scal/meta/is_constant_struct.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_constant_struct.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_IS_CONSTANT_STRUCT_HPP
2 #define STAN_MATH_PRIM_SCAL_META_IS_CONSTANT_STRUCT_HPP
3
4 #include <stan/math/prim/scal/meta/is_constant.hpp>
5
6 namespace stan {
7
12 template <typename T>
13 struct is_constant_struct {
14 enum { value = is_constant<T>::value };
15 };
16
17 }
18 #endif
stan::is_constant
Metaprogramming struct to detect whether a given type is constant in the mathematical sense (not the ...
Definition: is_constant.hpp:22
stan::is_constant_struct::value
Definition: is_constant_struct.hpp:14
stan
Definition: log_sum_exp.hpp:8
stan::is_constant_struct
Metaprogram to determine if a type has a base scalar type that can be assigned to type double...
Definition: is_constant_struct.hpp:13
is_constant.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.